=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2010-06-07 06:04:12 +0000
+++ drizzled/cursor.cc	2010-06-08 06:42:22 +0000
@@ -1458,7 +1458,9 @@
    * Cursor interface and into the fill_record() method.
    */
   if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_INSERT)
+  {
     table->timestamp_field->set_time();
+  }
 
   DRIZZLE_INSERT_ROW_START(table_share->getSchemaName(), table_share->getTableName());
   setTransactionReadWrite();
@@ -1508,6 +1510,11 @@
   }
   else
   {
+    if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
+    {
+      table->timestamp_field->set_time();
+    }
+
     error= doUpdateRecord(old_data, new_data);
     if (unlikely(plugin::EventObserver::afterUpdateRecord(*table, old_data, new_data, error)))
     {

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2010-06-07 06:04:12 +0000
+++ drizzled/sql_base.cc	2010-06-08 06:42:22 +0000
@@ -1429,7 +1429,9 @@
   assert(!table->auto_increment_field_not_null);
   table->auto_increment_field_not_null= false;
   if (table->timestamp_field)
+  {
     table->timestamp_field_type= table->timestamp_field->get_auto_set_type();
+  }
   table->pos_in_table_list= table_list;
   table->clear_column_bitmaps();
   assert(table->key_read == 0);

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2010-06-05 00:14:39 +0000
+++ drizzled/sql_insert.cc	2010-06-08 06:42:22 +0000
@@ -121,8 +121,10 @@
     if (table->timestamp_field)	// Don't automaticly set timestamp if used
     {
       if (table->timestamp_field->isWriteSet())
+      {
         clear_timestamp_auto_bits(table->timestamp_field_type,
                                   TIMESTAMP_AUTO_SET_ON_INSERT);
+      }
       else
       {
         table->setWriteSet(table->timestamp_field->field_index);
@@ -177,10 +179,15 @@
   {
     /* Don't set timestamp column if this is modified. */
     if (table->timestamp_field->isWriteSet())
+    {
       clear_timestamp_auto_bits(table->timestamp_field_type,
                                 TIMESTAMP_AUTO_SET_ON_UPDATE);
+    }
+
     if (timestamp_mark)
+    {
       table->setWriteSet(table->timestamp_field->field_index);
+    }
   }
   return 0;
 }

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2010-06-07 06:04:12 +0000
+++ drizzled/sql_update.cc	2010-06-08 06:42:22 +0000
@@ -175,12 +175,16 @@
   {
     // Don't set timestamp column if this is modified
     if (table->timestamp_field->isWriteSet())
+    {
       table->timestamp_field_type= TIMESTAMP_NO_AUTO_SET;
+    }
     else
     {
       if (table->timestamp_field_type == TIMESTAMP_AUTO_SET_ON_UPDATE ||
           table->timestamp_field_type == TIMESTAMP_AUTO_SET_ON_BOTH)
+      {
         table->setWriteSet(table->timestamp_field->field_index);
+      }
     }
   }
 
@@ -214,7 +218,9 @@
       table->timestamp_field &&
       (table->timestamp_field_type == TIMESTAMP_AUTO_SET_ON_UPDATE ||
        table->timestamp_field_type == TIMESTAMP_AUTO_SET_ON_BOTH))
+  {
     bitmap_union(table->read_set, table->write_set);
+  }
   // Don't count on usage of 'only index' when calculating which key to use
   table->covering_keys.reset();
 

=== modified file 'plugin/csv/ha_tina.cc'
--- plugin/csv/ha_tina.cc	2010-06-04 23:50:43 +0000
+++ plugin/csv/ha_tina.cc	2010-06-08 06:42:22 +0000
@@ -1005,9 +1005,6 @@
 
   ha_statistic_increment(&system_status_var::ha_update_count);
 
-  if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-    table->timestamp_field->set_time();
-
   size= encode_quote(new_data);
 
   /*

=== modified file 'plugin/embedded_innodb/embedded_innodb_engine.cc'
--- plugin/embedded_innodb/embedded_innodb_engine.cc	2010-06-07 06:04:12 +0000
+++ plugin/embedded_innodb/embedded_innodb_engine.cc	2010-06-08 06:42:22 +0000
@@ -1681,9 +1681,6 @@
   err= ib_tuple_copy(update_tuple, tuple);
   assert(err == DB_SUCCESS);
 
-  if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-    table->timestamp_field->set_time();
-
   write_row_to_innodb_tuple(table->getFields(), update_tuple);
 
   err= ib_cursor_update_row(cursor, tuple, update_tuple);

=== modified file 'plugin/heap/ha_heap.cc'
--- plugin/heap/ha_heap.cc	2010-06-08 03:11:02 +0000
+++ plugin/heap/ha_heap.cc	2010-06-08 06:42:22 +0000
@@ -347,8 +347,6 @@
 {
   int res;
   ha_statistic_increment(&system_status_var::ha_update_count);
-  if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-    table->timestamp_field->set_time();
   res= heap_update(file,old_data,new_data);
   if (!res && ++records_changed*MEMORY_STATS_UPDATE_THRESHOLD >
               file->s->records)

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-06-07 16:59:18 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-06-08 06:42:22 +0000
@@ -4163,9 +4163,6 @@
 
   ha_statistic_increment(&system_status_var::ha_update_count);
 
-  if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-    table->timestamp_field->set_time();
-
   if (prebuilt->upd_node) {
     uvect = prebuilt->upd_node->update;
   } else {

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2010-06-08 03:51:35 +0000
+++ plugin/myisam/ha_myisam.cc	2010-06-08 06:42:22 +0000
@@ -1034,8 +1034,6 @@
 int ha_myisam::doUpdateRecord(const unsigned char *old_data, unsigned char *new_data)
 {
   ha_statistic_increment(&system_status_var::ha_update_count);
-  if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-    table->timestamp_field->set_time();
   return mi_update(file,old_data,new_data);
 }
 

=== modified file 'plugin/pbxt/src/ha_pbxt.cc'
--- plugin/pbxt/src/ha_pbxt.cc	2010-05-26 10:17:56 +0000
+++ plugin/pbxt/src/ha_pbxt.cc	2010-06-08 06:42:22 +0000
@@ -2676,9 +2676,6 @@
 			pb_import_row_count++;
 	}
 
-	if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_INSERT)
-		table->timestamp_field->set_time();
-
 	if (table->next_number_field && buf == table->record[0]) {
 		int update_err = update_auto_increment();
 		if (update_err) {
@@ -2779,9 +2776,6 @@
 		pb_open_tab->ot_update_id++;
 	}
 
-	if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
-		table->timestamp_field->set_time();
-
 #ifdef PBMS_ENABLED
 	PBMSResultRec result;
 

